@@ -50,8 +50,8 @@ class AwsBackend(Backend):
 
     def submit_job(self, job: Job, counter: List[int]):
         jobs.create_job(self._s3_client(), self.backend_config.bucket_name, job, counter)
-        runners.run_job(self._ec2_client(), self._iam_client(), self._s3_client(), self.backend_config.bucket_name,
-                        self.backend_config.region_name, job)
+        runners.run_job(self._secretsmanager_client(), self._ec2_client(), self._iam_client(), self._s3_client(),
+                        self.backend_config.bucket_name, self.backend_config.region_name, job)
 
     def get_job(self, repo_user_name: str, repo_name: str, job_id: str) -> Optional[Job]:
         return jobs.get_job(self._s3_client(), self.backend_config.bucket_name, repo_user_name, repo_name, job_id)
@@ -65,8 +65,8 @@ class AwsBackend(Backend):
                               run_name)
 
     def run_job(self, job: Job) -> Runner:
-        return runners.run_job(self._ec2_client(), self._iam_client(), self._s3_client(),
-                               self.backend_config.bucket_name, self.backend_config.region_name, job)
+        return runners.run_job(self._secretsmanager_client(), self._ec2_client(), self._iam_client(),
+                               self._s3_client(), self.backend_config.bucket_name, self.backend_config.region_name, job)
 
     def stop_job(self, repo_user_name: str, repo_name: str, job_id: str, abort: bool):
         runners.stop_job(self._ec2_client(), self._s3_client(), self.backend_config.bucket_name, repo_user_name,
