@@ -207,6 +207,23 @@ def list_job_heads(s3_client: BaseClient, bucket_name: str, repo_user_name: str,
     return job_heads
 
 
+def list_job_head(s3_client: BaseClient, bucket_name: str, repo_user_name: str, repo_name: str, job_id: str) \
+        -> Optional[JobHead]:
+    prefix = f"jobs/{repo_user_name}/{repo_name}"
+    job_head_key_prefix = f"{prefix}/l;{job_id};"
+    response = s3_client.list_objects_v2(Bucket=bucket_name, Prefix=job_head_key_prefix)
+    if "Contents" in response:
+        for obj in response["Contents"]:
+            provider_name, submitted_at, status, artifacts, app_names, tag_name = tuple(
+                obj["Key"][len(job_head_key_prefix):].split(';'))
+            run_name, workflow_name, job_index = tuple(job_id.split(','))
+            return JobHead(job_id, repo_user_name, repo_name, run_name, workflow_name or None, provider_name,
+                           JobStatus(status), int(submitted_at),
+                           artifacts.split(',') if artifacts else None, tag_name or None,
+                           app_names or None)
+    return None
+
+
 def list_jobs(s3_client: BaseClient, bucket_name: str, repo_user_name: str, repo_name: str,
               run_name: Optional[str] = None) -> List[Job]:
     job_key_run_prefix = f"jobs/{repo_user_name}/{repo_name}/{run_name},"
