@@ -11,9 +11,16 @@ from dstack.config import ConfigError
 from dstack.repo import load_repo_data
 
 
+def _verb(abort: bool):
+    if abort:
+        return "Abort"
+    else:
+        return "Stop"
+
+
 def stop_func(args: Namespace):
-    if (args.run_name and (args.yes or Confirm.ask(f"[red]Stop the run '{args.run_name}'?[/]"))) \
-            or (args.all and (args.yes or Confirm.ask("[red]Stop all runs?[/]"))):
+    if (args.run_name and (args.yes or Confirm.ask(f"[red]{_verb(args.abort)} the run '{args.run_name}'?[/]"))) \
+            or (args.all and (args.yes or Confirm.ask(f"[red]{_verb(args.abort)} all runs?[/]"))):
         try:
             repo_data = load_repo_data()
             backend = load_backend()
@@ -39,7 +46,7 @@ def register_parsers(main_subparsers):
 
     parser.add_argument("run_name", metavar="RUN", type=str, nargs="?", help="A name of a run")
     parser.add_argument("-a", "--all", help="All runs", dest="all", action="store_true")
-    parser.add_argument("--abort", help="Don't wait for a graceful stop", dest="abort", action="store_true")
+    parser.add_argument("-x", "--abort", help="Don't wait for a graceful stop", dest="abort", action="store_true")
     parser.add_argument("--yes", "-y", help="Don't ask for confirmation", action="store_true")
 
     parser.set_defaults(func=stop_func)
